<?php
require 'vendor/autoload.php';
require 'LatteView.php';
require 'util.php';
require 'DatabaseAuthenticator.php';

/*
 * Set locale based on browser language specification
 * XXX: use for gettext
 */

//if ($locale = locale_accept_from_http($_SERVER['HTTP_ACCEPT_LANGUAGE']))
//    setlocale(LC_ALL, $locale, "$locale.utf8");

/*
 * Config
 */

$config = load_config('config.json');

if (($config_local = load_config('config.local.json', true)) !== null)
    $config = array_merge_recursive($config, $config_local);

define('ROOT_URL', $config['root_url']);

$view = new Slim\Latte\LatteView(array(
    'path' => __DIR__ . '/templates',
    'cache' => __DIR__ . '/.cache/latte',
    'configure_engine' => function ($engine) {
        $engine->onCompile[] = function ($latte) {
            Instante\Bootstrap3Renderer\Latte\FormMacros::install($latte->getCompiler());
        };
    }
));
$app = new Slim\Slim(array(
    'view' => $view
));

/*
 * Database setup
 */

$connection = new Nette\Database\Connection(
    $config['database']['dsn'],
    $config['database']['user'],
    $config['database']['password'],
    array(
        'lazy' => $config['database']['lazy']
    )
);
$db = new Nette\Database\Context($connection);

/*
 * Security
 */

$factory = new Nette\Http\RequestFactory;
$request = $factory->createHttpRequest();
$response = new Nette\Http\Response;
$session = new Nette\Http\Session($request, $response);
$storage = new Nette\Http\UserStorage($session);
$authenticator = new DatabaseAuthenticator($db);
$user = new Nette\Security\User($storage, $authenticator);

$app->hook('slim.before.router', function () use ($app, $user) {
    $url = $app->request()->getPathInfo();
    $non_user_urls = array('/login', '/register', '/populate');

    if (!in_array($url, $non_user_urls) && !$user->isLoggedIn())
        $app->redirect(ROOT_URL . '/login');
});

/*
 * Routes
 */

require 'routes/common.php';
require 'routes/register.php';
require 'routes/user.php';
require 'routes/match.php';

// XXX: debug code
require 'populate.php';

$view->replace(compact('app', 'config', 'user'));
$app->run();
