<?php

function pack_scores($scores) {
    $blob = '';
    foreach ($scores as $score)
        $blob .= pack('C', $score);
    return $blob;
}

function unpack_scores($blob) {
    return array_map(function($c) { return unpack('C', $c)[1]; }, str_split($blob));
}

function match_arrows($row) {
    return sprintf('%d &times; %d', $row->turns, $row->arrows);
}

function match_score($row) {
    return array_sum(unpack_scores($row->scores));
}

function match_avg_score($row) {
    return match_score($row) / ($row->turns * $row->arrows);
}

function find_match($id) {
    global $app, $db, $user;
    $match = $db->table('match')->get($id);

    if (!$match)
        $app->halt(404, 'Match does not exist');

    if ($match->user_id != $user->getId() && !$user->hasRole('admin'))
        $app->halt(403, 'You are not allowed to view this match');

    return $match;
}

function render_match_action($action) {
    return function($id) use ($action) {
        global $app;
        $app->render("match/$action", array('match' => find_match($id)));
    };
}

$app->get('/match', function () use ($app, $db, $user) {
    $user_id = $user->getId();
    $matches = $db->table('match')->where(compact('user_id'))->order('created_at', 'desc');
    $app->render('match/list', compact('matches'));
});
$app->get('/match/:id', render_match_action('view'));
$app->get('/match/:id/edit', render_match_action('edit'));
$app->get('/match/:id/delete', render_match_action('delete'));

$app->delete('/match/:id', function ($id) use ($app, $db) {
    $db->table('user')->delete();
    //find_match($id)->delete();
});
